# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analysis_computation.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'analysis_computation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_pb2 as analysis__pb2
try:
  common__models__pb2 = analysis__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61nalysis_computation.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x0e\x61nalysis.proto\"i\n AnalysisComputationCreateRequest\x12\x1a\n\x12\x61nalysis_config_id\x18\x01 \x01(\t\x12\x0e\n\x06toi_id\x18\x02 \x01(\t\x12\x19\n\x11\x61oi_collection_id\x18\x03 \x01(\t\"t\n!AnalysisComputationCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12:\n\x14\x61nalysis_computation\x18\x02 \x01(\x0b\x32\x1c.oi.papi.AnalysisComputation\",\n\x1d\x41nalysisComputationRunRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"5\n\x1e\x41nalysisComputationRunResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"U\n\x1d\x41nalysisComputationGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"f\n\x17\x41nalysisComputationNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x63omputation_id\x18\x02 \x01(\t\x12\x10\n\x08\x63hildren\x18\x03 \x03(\t\x12\x13\n\x0bhas_results\x18\x04 \x01(\x08\"\xf0\x03\n\x13\x41nalysisComputation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x61nalysis_id\x18\x02 \x01(\t\x12\x0e\n\x06toi_id\x18\x03 \x01(\t\x12\x19\n\x11\x61oi_collection_id\x18\x04 \x01(\t\x12\x1a\n\x12\x61nalysis_config_id\x18\x05 \x01(\t\x12\x30\n\x0csubmitted_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x05state\x18\x07 \x01(\x0e\x32\".oi.papi.AnalysisComputation.State\x12;\n\x11\x63omputation_nodes\x18\x08 \x03(\x0b\x32 .oi.papi.AnalysisComputationNode\x12\x37\n\x08progress\x18\t \x01(\x0b\x32%.oi.papi.AnalysisComputation.Progress\x1a>\n\x08Progress\x12\x0f\n\x07running\x18\x01 \x01(\x01\x12\x11\n\tsucceeded\x18\x02 \x01(\x01\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x01\"V\n\x05State\x12\x11\n\rUNKNOWN_STATE\x10\x00\x12\x0f\n\x0bNOT_STARTED\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\x0c\n\x08\x43OMPLETE\x10\x04\"\x9b\x01\n\x1e\x41nalysisComputationGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12;\n\x15\x61nalysis_computations\x18\x02 \x03(\x0b\x32\x1c.oi.papi.AnalysisComputation\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xb0\x02\n\x1e\x41nalysisComputationListRequest\x12\r\n\x05state\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x34\n\x10min_submitted_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10max_submitted_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12\x61nalysis_config_id\x18\x05 \x01(\t\x12\x0e\n\x06toi_id\x18\x06 \x01(\t\x12\x19\n\x11\x61oi_collection_id\x18\x07 \x01(\t\x12\x13\n\x0b\x61nalysis_id\x18\x08 \x01(\t\x12\'\n\npagination\x18\t \x01(\x0b\x32\x13.oi.papi.Pagination\"\x9c\x01\n\x1f\x41nalysisComputationListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12;\n\x15\x61nalysis_computations\x18\x02 \x03(\x0b\x32\x1c.oi.papi.AnalysisComputation\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\x84\x03\n\x16\x41nalysisComputationApi\x12_\n\x06\x63reate\x12).oi.papi.AnalysisComputationCreateRequest\x1a*.oi.papi.AnalysisComputationCreateResponse\x12V\n\x03run\x12&.oi.papi.AnalysisComputationRunRequest\x1a\'.oi.papi.AnalysisComputationRunResponse\x12V\n\x03get\x12&.oi.papi.AnalysisComputationGetRequest\x1a\'.oi.papi.AnalysisComputationGetResponse\x12Y\n\x04list\x12\'.oi.papi.AnalysisComputationListRequest\x1a(.oi.papi.AnalysisComputationListResponseP\x01P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analysis_computation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYSISCOMPUTATIONCREATEREQUEST']._serialized_start=109
  _globals['_ANALYSISCOMPUTATIONCREATEREQUEST']._serialized_end=214
  _globals['_ANALYSISCOMPUTATIONCREATERESPONSE']._serialized_start=216
  _globals['_ANALYSISCOMPUTATIONCREATERESPONSE']._serialized_end=332
  _globals['_ANALYSISCOMPUTATIONRUNREQUEST']._serialized_start=334
  _globals['_ANALYSISCOMPUTATIONRUNREQUEST']._serialized_end=378
  _globals['_ANALYSISCOMPUTATIONRUNRESPONSE']._serialized_start=380
  _globals['_ANALYSISCOMPUTATIONRUNRESPONSE']._serialized_end=433
  _globals['_ANALYSISCOMPUTATIONGETREQUEST']._serialized_start=435
  _globals['_ANALYSISCOMPUTATIONGETREQUEST']._serialized_end=520
  _globals['_ANALYSISCOMPUTATIONNODE']._serialized_start=522
  _globals['_ANALYSISCOMPUTATIONNODE']._serialized_end=624
  _globals['_ANALYSISCOMPUTATION']._serialized_start=627
  _globals['_ANALYSISCOMPUTATION']._serialized_end=1123
  _globals['_ANALYSISCOMPUTATION_PROGRESS']._serialized_start=973
  _globals['_ANALYSISCOMPUTATION_PROGRESS']._serialized_end=1035
  _globals['_ANALYSISCOMPUTATION_STATE']._serialized_start=1037
  _globals['_ANALYSISCOMPUTATION_STATE']._serialized_end=1123
  _globals['_ANALYSISCOMPUTATIONGETRESPONSE']._serialized_start=1126
  _globals['_ANALYSISCOMPUTATIONGETRESPONSE']._serialized_end=1281
  _globals['_ANALYSISCOMPUTATIONLISTREQUEST']._serialized_start=1284
  _globals['_ANALYSISCOMPUTATIONLISTREQUEST']._serialized_end=1588
  _globals['_ANALYSISCOMPUTATIONLISTRESPONSE']._serialized_start=1591
  _globals['_ANALYSISCOMPUTATIONLISTRESPONSE']._serialized_end=1747
  _globals['_ANALYSISCOMPUTATIONAPI']._serialized_start=1750
  _globals['_ANALYSISCOMPUTATIONAPI']._serialized_end=2138
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import analysis_computation_pb2 as analysis__computation__pb2

GRPC_GENERATED_VERSION = '1.68.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in analysis_computation_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AnalysisComputationApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AnalysisComputationApi/create',
                request_serializer=analysis__computation__pb2.AnalysisComputationCreateRequest.SerializeToString,
                response_deserializer=analysis__computation__pb2.AnalysisComputationCreateResponse.FromString,
                _registered_method=True)
        self.run = channel.unary_unary(
                '/oi.papi.AnalysisComputationApi/run',
                request_serializer=analysis__computation__pb2.AnalysisComputationRunRequest.SerializeToString,
                response_deserializer=analysis__computation__pb2.AnalysisComputationRunResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.AnalysisComputationApi/get',
                request_serializer=analysis__computation__pb2.AnalysisComputationGetRequest.SerializeToString,
                response_deserializer=analysis__computation__pb2.AnalysisComputationGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.AnalysisComputationApi/list',
                request_serializer=analysis__computation__pb2.AnalysisComputationListRequest.SerializeToString,
                response_deserializer=analysis__computation__pb2.AnalysisComputationListResponse.FromString,
                _registered_method=True)


class AnalysisComputationApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create the runnable component in the system, by specifying the Analysis to be run, the set of AOIs to be run on, and the TOI.
        The analysis_computation_id is returned so that it can be run.
        Note that until an AnalysisComputation has been run, its underlying resources are NOT locked and therefore can be changed.
        The names of an AlgorithmComputationNode must match that of it's corresponding Analysis' AnalysisAlgorithmNode.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def run(self, request, context):
        """
        The first time this endpoint is called, the system initiates the running of the provided analysis_computation_id.
        This causes credits to be place in pending status and eventually consumed when the AnalysisComputation completes.
        Credits are consumed as each result is produced. Once an Analysis has been run, all of its underlying constituent parts are considered locked and cannot be modified.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Retrieves the details of the provided AnalysisComputation including its current state and its progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Lists the details for all AnalysisComputations that the requester has access to including their current state and their progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnalysisComputationApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=analysis__computation__pb2.AnalysisComputationCreateRequest.FromString,
                    response_serializer=analysis__computation__pb2.AnalysisComputationCreateResponse.SerializeToString,
            ),
            'run': grpc.unary_unary_rpc_method_handler(
                    servicer.run,
                    request_deserializer=analysis__computation__pb2.AnalysisComputationRunRequest.FromString,
                    response_serializer=analysis__computation__pb2.AnalysisComputationRunResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=analysis__computation__pb2.AnalysisComputationGetRequest.FromString,
                    response_serializer=analysis__computation__pb2.AnalysisComputationGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=analysis__computation__pb2.AnalysisComputationListRequest.FromString,
                    response_serializer=analysis__computation__pb2.AnalysisComputationListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AnalysisComputationApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AnalysisComputationApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AnalysisComputationApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AnalysisComputationApi/create',
            analysis__computation__pb2.AnalysisComputationCreateRequest.SerializeToString,
            analysis__computation__pb2.AnalysisComputationCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def run(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AnalysisComputationApi/run',
            analysis__computation__pb2.AnalysisComputationRunRequest.SerializeToString,
            analysis__computation__pb2.AnalysisComputationRunResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AnalysisComputationApi/get',
            analysis__computation__pb2.AnalysisComputationGetRequest.SerializeToString,
            analysis__computation__pb2.AnalysisComputationGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AnalysisComputationApi/list',
            analysis__computation__pb2.AnalysisComputationListRequest.SerializeToString,
            analysis__computation__pb2.AnalysisComputationListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import user_pb2 as user__pb2

GRPC_GENERATED_VERSION = '1.68.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in user_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UserApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.login = channel.unary_unary(
                '/oi.papi.UserApi/login',
                request_serializer=user__pb2.LoginRequest.SerializeToString,
                response_deserializer=user__pb2.LoginResponse.FromString,
                _registered_method=True)
        self.change_password = channel.unary_unary(
                '/oi.papi.UserApi/change_password',
                request_serializer=user__pb2.UserChangePasswordRequest.SerializeToString,
                response_deserializer=user__pb2.UserChangePasswordResponse.FromString,
                _registered_method=True)
        self.generate_temp_password = channel.unary_unary(
                '/oi.papi.UserApi/generate_temp_password',
                request_serializer=user__pb2.UserGenerateTempPasswordRequest.SerializeToString,
                response_deserializer=user__pb2.UserGenerateTempPasswordResponse.FromString,
                _registered_method=True)
        self.create = channel.unary_unary(
                '/oi.papi.UserApi/create',
                request_serializer=user__pb2.UserCreateRequest.SerializeToString,
                response_deserializer=user__pb2.UserCreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.UserApi/get',
                request_serializer=user__pb2.UserGetRequest.SerializeToString,
                response_deserializer=user__pb2.UserGetResponse.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/oi.papi.UserApi/update',
                request_serializer=user__pb2.UserUpdateRequest.SerializeToString,
                response_deserializer=user__pb2.UserUpdateResponse.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/oi.papi.UserApi/delete',
                request_serializer=user__pb2.UserDeleteRequest.SerializeToString,
                response_deserializer=user__pb2.UserDeleteResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.UserApi/list',
                request_serializer=user__pb2.UserListRequest.SerializeToString,
                response_deserializer=user__pb2.UserListResponse.FromString,
                _registered_method=True)
        self.get_properties = channel.unary_unary(
                '/oi.papi.UserApi/get_properties',
                request_serializer=user__pb2.UserPropertiesGetRequest.SerializeToString,
                response_deserializer=user__pb2.UserPropertiesGetResponse.FromString,
                _registered_method=True)
        self.update_properties = channel.unary_unary(
                '/oi.papi.UserApi/update_properties',
                request_serializer=user__pb2.UserPropertiesUpdateRequest.SerializeToString,
                response_deserializer=user__pb2.UserPropertiesUpdateResponse.FromString,
                _registered_method=True)
        self.get_public_key = channel.unary_unary(
                '/oi.papi.UserApi/get_public_key',
                request_serializer=user__pb2.UserPublicKeyRequest.SerializeToString,
                response_deserializer=user__pb2.UserPublicKeyResponse.FromString,
                _registered_method=True)


class UserApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def login(self, request, context):
        """
        Login using user's email and password.
        The endpoint returns a JWT access token that is needed to use the API.
        Note: This endpoint does NOT require token authentication.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def change_password(self, request, context):
        """
        Change current User's password
        Note: This is an authenticated endpoint, but still requires old password to be sent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def generate_temp_password(self, request, context):
        """
        Create a temporary password for User
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """
        Create a new User in the system, assigned to the specified department.
        This functionality is only available for an admin user.
        This automatically creates an AOICollection associated to this user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Returns the details of the specified User. If no User is given, returns details for the requesting User.
        The specified User must belong to the same UserCollection as the requesting User, otherwise an error is thrown.
        The user_id is a uuid and is actually the folder ID, so its a subject ID. Access limitations apply.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Updates the details of the specified User. If no User is given, returns details for the requesting User.
        user is identified by id(uuid) field, remaining fields contain information to set
        Access limitations apply.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Delete the User specified by its id(UUID), which must be set. Requesting user cannot be deleted implicitly
        Access limitations apply.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        List users. Access limitations apply.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_properties(self, request, context):
        """
        Returns properties for the requesting User.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_properties(self, request, context):
        """
        Updates properties for the requesting User.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_public_key(self, request, context):
        """
        Get public key for the requesting User.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'login': grpc.unary_unary_rpc_method_handler(
                    servicer.login,
                    request_deserializer=user__pb2.LoginRequest.FromString,
                    response_serializer=user__pb2.LoginResponse.SerializeToString,
            ),
            'change_password': grpc.unary_unary_rpc_method_handler(
                    servicer.change_password,
                    request_deserializer=user__pb2.UserChangePasswordRequest.FromString,
                    response_serializer=user__pb2.UserChangePasswordResponse.SerializeToString,
            ),
            'generate_temp_password': grpc.unary_unary_rpc_method_handler(
                    servicer.generate_temp_password,
                    request_deserializer=user__pb2.UserGenerateTempPasswordRequest.FromString,
                    response_serializer=user__pb2.UserGenerateTempPasswordResponse.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=user__pb2.UserCreateRequest.FromString,
                    response_serializer=user__pb2.UserCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=user__pb2.UserGetRequest.FromString,
                    response_serializer=user__pb2.UserGetResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=user__pb2.UserUpdateRequest.FromString,
                    response_serializer=user__pb2.UserUpdateResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=user__pb2.UserDeleteRequest.FromString,
                    response_serializer=user__pb2.UserDeleteResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=user__pb2.UserListRequest.FromString,
                    response_serializer=user__pb2.UserListResponse.SerializeToString,
            ),
            'get_properties': grpc.unary_unary_rpc_method_handler(
                    servicer.get_properties,
                    request_deserializer=user__pb2.UserPropertiesGetRequest.FromString,
                    response_serializer=user__pb2.UserPropertiesGetResponse.SerializeToString,
            ),
            'update_properties': grpc.unary_unary_rpc_method_handler(
                    servicer.update_properties,
                    request_deserializer=user__pb2.UserPropertiesUpdateRequest.FromString,
                    response_serializer=user__pb2.UserPropertiesUpdateResponse.SerializeToString,
            ),
            'get_public_key': grpc.unary_unary_rpc_method_handler(
                    servicer.get_public_key,
                    request_deserializer=user__pb2.UserPublicKeyRequest.FromString,
                    response_serializer=user__pb2.UserPublicKeyResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.UserApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.UserApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/login',
            user__pb2.LoginRequest.SerializeToString,
            user__pb2.LoginResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def change_password(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/change_password',
            user__pb2.UserChangePasswordRequest.SerializeToString,
            user__pb2.UserChangePasswordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def generate_temp_password(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/generate_temp_password',
            user__pb2.UserGenerateTempPasswordRequest.SerializeToString,
            user__pb2.UserGenerateTempPasswordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/create',
            user__pb2.UserCreateRequest.SerializeToString,
            user__pb2.UserCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/get',
            user__pb2.UserGetRequest.SerializeToString,
            user__pb2.UserGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/update',
            user__pb2.UserUpdateRequest.SerializeToString,
            user__pb2.UserUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/delete',
            user__pb2.UserDeleteRequest.SerializeToString,
            user__pb2.UserDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/list',
            user__pb2.UserListRequest.SerializeToString,
            user__pb2.UserListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_properties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/get_properties',
            user__pb2.UserPropertiesGetRequest.SerializeToString,
            user__pb2.UserPropertiesGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update_properties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/update_properties',
            user__pb2.UserPropertiesUpdateRequest.SerializeToString,
            user__pb2.UserPropertiesUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_public_key(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserApi/get_public_key',
            user__pb2.UserPublicKeyRequest.SerializeToString,
            user__pb2.UserPublicKeyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'project.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_config_pb2 as analysis__config__pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__version__pb2 = analysis__config__pb2.analysis__version__pb2
except AttributeError:
  analysis__version__pb2 = analysis__config__pb2.analysis_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__config__pb2 = analysis__config__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = analysis__config__pb2.algorithm_config_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
from terrascope_api.models import analysis_computation_pb2 as analysis__computation__pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__computation__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__computation__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
from terrascope_api.models import aoi_collection_pb2 as aoi__collection__pb2
try:
  common__models__pb2 = aoi__collection__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__collection__pb2.common_models_pb2
from terrascope_api.models import result_pb2 as result__pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
try:
  toi__pb2 = result__pb2.toi__pb2
except AttributeError:
  toi__pb2 = result__pb2.toi_pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
from terrascope_api.models import project_filter_pb2 as project__filter__pb2
try:
  common__models__pb2 = project__filter__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__filter__pb2.common_models_pb2
try:
  filter__pb2 = project__filter__pb2.filter__pb2
except AttributeError:
  filter__pb2 = project__filter__pb2.filter_pb2
try:
  common__models__pb2 = project__filter__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__filter__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_config_pb2 import *
from terrascope_api.models.analysis_computation_pb2 import *
from terrascope_api.models.aoi_collection_pb2 import *
from terrascope_api.models.result_pb2 import *
from terrascope_api.models.project_filter_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rproject.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x15\x61nalysis_config.proto\x1a\x1a\x61nalysis_computation.proto\x1a\x14\x61oi_collection.proto\x1a\x0cresult.proto\x1a\x14project_filter.proto\"\x9f\x06\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12.\n\x06status\x18\x05 \x01(\x0e\x32\x1e.oi.papi.Project.ProjectStatus\x12/\n\x0f\x61oi_collections\x18\x06 \x03(\x0b\x32\x16.oi.papi.AOICollection\x12;\n\x15\x61nalysis_computations\x18\x07 \x03(\x0b\x32\x1c.oi.papi.AnalysisComputation\x12\x31\n\x10\x61nalysis_configs\x18\x08 \x03(\x0b\x32\x17.oi.papi.AnalysisConfig\x12.\n\nstart_date\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_ts\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x11\x61vailable_filters\x18\x0c \x03(\x0b\x32\x16.oi.papi.ProjectFilter\x12/\n\x0f\x61pplied_filters\x18\r \x03(\x0b\x32\x16.oi.papi.ProjectFilter\x12/\n\x0btime_ranges\x18\x0e \x03(\x0b\x32\x1a.oi.papi.Project.TimeRange\x12\x0c\n\x04type\x18\x0f \x01(\t\x1a_\n\tTimeRange\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"q\n\rProjectStatus\x12\x1a\n\x16UNKNOWN_PROJECT_STATUS\x10\x00\x12\r\n\tCOMPLETED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\x12\x0f\n\x0bNOT_STARTED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\"=\n\x12ProjectListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\"w\n\x13ProjectListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\"\n\x08projects\x18\x02 \x03(\x0b\x32\x10.oi.papi.Project\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x1f\n\x11ProjectGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"L\n\x12ProjectGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\"9\n\x14ProjectCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"O\n\x15ProjectCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\":\n\x14ProjectUpdateRequest\x12\"\n\x08projects\x18\x01 \x03(\x0b\x32\x10.oi.papi.Project\",\n\x15ProjectUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"#\n\x14ProjectDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\",\n\x15ProjectDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\" \n\x11ProjectRunRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\")\n\x12ProjectRunResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"!\n\x13ProjectCloneRequest\x12\n\n\x02id\x18\x01 \x01(\t\"N\n\x14ProjectCloneResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\"2\n\x1cProjectCreditEstimateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x88\x01\n\x1dProjectCreditEstimateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x17\n\x0f\x61pplied_credits\x18\x02 \x01(\x01\x12\x13\n\x0bnew_credits\x18\x03 \x01(\x01\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x13\n\x0bis_runnable\x18\x05 \x01(\x08\"1\n\x1bProjectRequestAccessRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"3\n\x1cProjectRequestAccessResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xb1\x05\n\nProjectApi\x12\x41\n\x04list\x12\x1b.oi.papi.ProjectListRequest\x1a\x1c.oi.papi.ProjectListResponse\x12>\n\x03get\x12\x1a.oi.papi.ProjectGetRequest\x1a\x1b.oi.papi.ProjectGetResponse\x12G\n\x06\x63reate\x12\x1d.oi.papi.ProjectCreateRequest\x1a\x1e.oi.papi.ProjectCreateResponse\x12G\n\x06update\x12\x1d.oi.papi.ProjectUpdateRequest\x1a\x1e.oi.papi.ProjectUpdateResponse\x12G\n\x06\x64\x65lete\x12\x1d.oi.papi.ProjectDeleteRequest\x1a\x1e.oi.papi.ProjectDeleteResponse\x12>\n\x03run\x12\x1a.oi.papi.ProjectRunRequest\x1a\x1b.oi.papi.ProjectRunResponse\x12\x44\n\x05\x63lone\x12\x1c.oi.papi.ProjectCloneRequest\x1a\x1d.oi.papi.ProjectCloneResponse\x12`\n\x0f\x63redit_estimate\x12%.oi.papi.ProjectCreditEstimateRequest\x1a&.oi.papi.ProjectCreditEstimateResponse\x12]\n\x0erequest_access\x12$.oi.papi.ProjectRequestAccessRequest\x1a%.oi.papi.ProjectRequestAccessResponseP\x01P\x02P\x03P\x04P\x05P\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECT']._serialized_start=190
  _globals['_PROJECT']._serialized_end=989
  _globals['_PROJECT_TIMERANGE']._serialized_start=779
  _globals['_PROJECT_TIMERANGE']._serialized_end=874
  _globals['_PROJECT_PROJECTSTATUS']._serialized_start=876
  _globals['_PROJECT_PROJECTSTATUS']._serialized_end=989
  _globals['_PROJECTLISTREQUEST']._serialized_start=991
  _globals['_PROJECTLISTREQUEST']._serialized_end=1052
  _globals['_PROJECTLISTRESPONSE']._serialized_start=1054
  _globals['_PROJECTLISTRESPONSE']._serialized_end=1173
  _globals['_PROJECTGETREQUEST']._serialized_start=1175
  _globals['_PROJECTGETREQUEST']._serialized_end=1206
  _globals['_PROJECTGETRESPONSE']._serialized_start=1208
  _globals['_PROJECTGETRESPONSE']._serialized_end=1284
  _globals['_PROJECTCREATEREQUEST']._serialized_start=1286
  _globals['_PROJECTCREATEREQUEST']._serialized_end=1343
  _globals['_PROJECTCREATERESPONSE']._serialized_start=1345
  _globals['_PROJECTCREATERESPONSE']._serialized_end=1424
  _globals['_PROJECTUPDATEREQUEST']._serialized_start=1426
  _globals['_PROJECTUPDATEREQUEST']._serialized_end=1484
  _globals['_PROJECTUPDATERESPONSE']._serialized_start=1486
  _globals['_PROJECTUPDATERESPONSE']._serialized_end=1530
  _globals['_PROJECTDELETEREQUEST']._serialized_start=1532
  _globals['_PROJECTDELETEREQUEST']._serialized_end=1567
  _globals['_PROJECTDELETERESPONSE']._serialized_start=1569
  _globals['_PROJECTDELETERESPONSE']._serialized_end=1613
  _globals['_PROJECTRUNREQUEST']._serialized_start=1615
  _globals['_PROJECTRUNREQUEST']._serialized_end=1647
  _globals['_PROJECTRUNRESPONSE']._serialized_start=1649
  _globals['_PROJECTRUNRESPONSE']._serialized_end=1690
  _globals['_PROJECTCLONEREQUEST']._serialized_start=1692
  _globals['_PROJECTCLONEREQUEST']._serialized_end=1725
  _globals['_PROJECTCLONERESPONSE']._serialized_start=1727
  _globals['_PROJECTCLONERESPONSE']._serialized_end=1805
  _globals['_PROJECTCREDITESTIMATEREQUEST']._serialized_start=1807
  _globals['_PROJECTCREDITESTIMATEREQUEST']._serialized_end=1857
  _globals['_PROJECTCREDITESTIMATERESPONSE']._serialized_start=1860
  _globals['_PROJECTCREDITESTIMATERESPONSE']._serialized_end=1996
  _globals['_PROJECTREQUESTACCESSREQUEST']._serialized_start=1998
  _globals['_PROJECTREQUESTACCESSREQUEST']._serialized_end=2047
  _globals['_PROJECTREQUESTACCESSRESPONSE']._serialized_start=2049
  _globals['_PROJECTREQUESTACCESSRESPONSE']._serialized_end=2100
  _globals['_PROJECTAPI']._serialized_start=2103
  _globals['_PROJECTAPI']._serialized_end=2792
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: order_recommendation.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'order_recommendation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aorder_recommendation.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcd\x01\n\x13OrderRecommendation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\x15\n\rjustification\x18\x03 \x01(\t\x12\x0c\n\x04team\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontact_info\x18\x05 \x01(\t\x12.\n\nexpiration\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_on\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9f\x01\n OrderRecommendationCreateRequest\x12\x10\n\x08order_id\x18\x02 \x01(\t\x12\x15\n\rjustification\x18\x03 \x01(\t\x12\x0c\n\x04team\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontact_info\x18\x05 \x01(\t\x12.\n\nexpiration\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"t\n!OrderRecommendationCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12:\n\x14order_recommendation\x18\x02 \x01(\x0b\x32\x1c.oi.papi.OrderRecommendation\"\xae\x01\n OrderRecommendationUpdateRequest\x12\x1f\n\x17order_recommendation_id\x18\x01 \x01(\t\x12\x15\n\rjustification\x18\x02 \x01(\t\x12\x0c\n\x04team\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontact_info\x18\x04 \x01(\t\x12.\n\nexpiration\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"t\n!OrderRecommendationUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12:\n\x14order_recommendation\x18\x02 \x01(\x0b\x32\x1c.oi.papi.OrderRecommendation\"C\n OrderRecommendationDeleteRequest\x12\x1f\n\x17order_recommendation_id\x18\x01 \x01(\t\"8\n!OrderRecommendationDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xbb\x02\n\x16OrderRecommendationApi\x12_\n\x06\x63reate\x12).oi.papi.OrderRecommendationCreateRequest\x1a*.oi.papi.OrderRecommendationCreateResponse\x12_\n\x06update\x12).oi.papi.OrderRecommendationUpdateRequest\x1a*.oi.papi.OrderRecommendationUpdateResponse\x12_\n\x06\x64\x65lete\x12).oi.papi.OrderRecommendationDeleteRequest\x1a*.oi.papi.OrderRecommendationDeleteResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'order_recommendation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERRECOMMENDATION']._serialized_start=73
  _globals['_ORDERRECOMMENDATION']._serialized_end=278
  _globals['_ORDERRECOMMENDATIONCREATEREQUEST']._serialized_start=281
  _globals['_ORDERRECOMMENDATIONCREATEREQUEST']._serialized_end=440
  _globals['_ORDERRECOMMENDATIONCREATERESPONSE']._serialized_start=442
  _globals['_ORDERRECOMMENDATIONCREATERESPONSE']._serialized_end=558
  _globals['_ORDERRECOMMENDATIONUPDATEREQUEST']._serialized_start=561
  _globals['_ORDERRECOMMENDATIONUPDATEREQUEST']._serialized_end=735
  _globals['_ORDERRECOMMENDATIONUPDATERESPONSE']._serialized_start=737
  _globals['_ORDERRECOMMENDATIONUPDATERESPONSE']._serialized_end=853
  _globals['_ORDERRECOMMENDATIONDELETEREQUEST']._serialized_start=855
  _globals['_ORDERRECOMMENDATIONDELETEREQUEST']._serialized_end=922
  _globals['_ORDERRECOMMENDATIONDELETERESPONSE']._serialized_start=924
  _globals['_ORDERRECOMMENDATIONDELETERESPONSE']._serialized_end=980
  _globals['_ORDERRECOMMENDATIONAPI']._serialized_start=983
  _globals['_ORDERRECOMMENDATIONAPI']._serialized_end=1298
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tasking_order.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'tasking_order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import order_recommendation_pb2 as order__recommendation__pb2
from terrascope_api.models import order_pb2 as order__pb2
try:
  order__recommendation__pb2 = order__pb2.order__recommendation__pb2
except AttributeError:
  order__recommendation__pb2 = order__pb2.order_recommendation_pb2

from terrascope_api.models.order_recommendation_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13tasking_order.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1aorder_recommendation.proto\x1a\x0border.proto\"j\n\tTimeRange\x12-\n\tstart_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nfinish_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xce\x03\n\x0cTaskingOrder\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x13\n\x0btarget_geom\x18\x03 \x01(\x0c\x12&\n\nacq_window\x18\x04 \x01(\x0b\x32\x12.oi.papi.TimeRange\x12\x19\n\x11product_spec_name\x18\x05 \x01(\t\x12\"\n\x05state\x18\x06 \x01(\x0e\x32\x13.oi.papi.OrderState\x12\x0f\n\x07\x64\x65tails\x18\x07 \x01(\t\x12\x0b\n\x03url\x18\x08 \x01(\t\x12)\n\x08metadata\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x63reator\x18\n \x01(\t\x12.\n\ncreated_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x61pproved_by\x18\r \x01(\t\x12\x18\n\x10\x61pproval_comment\x18\x0e \x01(\t\x12\x35\n\x0frecommendations\x18\x0f \x03(\x0b\x32\x1c.oi.papi.OrderRecommendation\"\x9c\x01\n\x17TaskingOrderListRequest\x12#\n\x06states\x18\x01 \x03(\x0e\x32\x13.oi.papi.OrderState\x12\x17\n\x0f\x64\x61ta_source_ids\x18\x02 \x03(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x03 \x03(\t\x12!\n\x19\x61lgorithm_computation_ids\x18\x04 \x03(\t\"V\n\x18TaskingOrderListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\x06orders\x18\x02 \x03(\x0b\x32\x15.oi.papi.TaskingOrder\"$\n\x16TaskingOrderGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"T\n\x17TaskingOrderGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\x05order\x18\x02 \x01(\x0b\x32\x15.oi.papi.TaskingOrder\"9\n\x1aTaskingOrderApproveRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"2\n\x1bTaskingOrderApproveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xb6\x01\n\x19TaskingOrderCreateRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x19\n\x11product_spec_name\x18\x02 \x01(\t\x12\x13\n\x0btarget_geom\x18\x03 \x01(\x0c\x12&\n\nacq_window\x18\x04 \x01(\x0b\x32\x12.oi.papi.TimeRange\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"W\n\x1aTaskingOrderCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\x05order\x18\x02 \x01(\x0b\x32\x15.oi.papi.TaskingOrder\"\'\n\x19TaskingOrderCancelRequest\x12\n\n\x02id\x18\x01 \x01(\t\"1\n\x1aTaskingOrderCancelResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xa4\x03\n\x0fTaskingOrderApi\x12K\n\x04list\x12 .oi.papi.TaskingOrderListRequest\x1a!.oi.papi.TaskingOrderListResponse\x12H\n\x03get\x12\x1f.oi.papi.TaskingOrderGetRequest\x1a .oi.papi.TaskingOrderGetResponse\x12Q\n\x06\x63reate\x12\".oi.papi.TaskingOrderCreateRequest\x1a#.oi.papi.TaskingOrderCreateResponse\x12T\n\x07\x61pprove\x12#.oi.papi.TaskingOrderApproveRequest\x1a$.oi.papi.TaskingOrderApproveResponse\x12Q\n\x06\x63\x61ncel\x12\".oi.papi.TaskingOrderCancelRequest\x1a#.oi.papi.TaskingOrderCancelResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasking_order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TIMERANGE']._serialized_start=136
  _globals['_TIMERANGE']._serialized_end=242
  _globals['_TASKINGORDER']._serialized_start=245
  _globals['_TASKINGORDER']._serialized_end=707
  _globals['_TASKINGORDERLISTREQUEST']._serialized_start=710
  _globals['_TASKINGORDERLISTREQUEST']._serialized_end=866
  _globals['_TASKINGORDERLISTRESPONSE']._serialized_start=868
  _globals['_TASKINGORDERLISTRESPONSE']._serialized_end=954
  _globals['_TASKINGORDERGETREQUEST']._serialized_start=956
  _globals['_TASKINGORDERGETREQUEST']._serialized_end=992
  _globals['_TASKINGORDERGETRESPONSE']._serialized_start=994
  _globals['_TASKINGORDERGETRESPONSE']._serialized_end=1078
  _globals['_TASKINGORDERAPPROVEREQUEST']._serialized_start=1080
  _globals['_TASKINGORDERAPPROVEREQUEST']._serialized_end=1137
  _globals['_TASKINGORDERAPPROVERESPONSE']._serialized_start=1139
  _globals['_TASKINGORDERAPPROVERESPONSE']._serialized_end=1189
  _globals['_TASKINGORDERCREATEREQUEST']._serialized_start=1192
  _globals['_TASKINGORDERCREATEREQUEST']._serialized_end=1374
  _globals['_TASKINGORDERCREATERESPONSE']._serialized_start=1376
  _globals['_TASKINGORDERCREATERESPONSE']._serialized_end=1463
  _globals['_TASKINGORDERCANCELREQUEST']._serialized_start=1465
  _globals['_TASKINGORDERCANCELREQUEST']._serialized_end=1504
  _globals['_TASKINGORDERCANCELRESPONSE']._serialized_start=1506
  _globals['_TASKINGORDERCANCELRESPONSE']._serialized_end=1555
  _globals['_TASKINGORDERAPI']._serialized_start=1558
  _globals['_TASKINGORDERAPI']._serialized_end=1978
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_result.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'project_result.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import result_pb2 as result__pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
try:
  toi__pb2 = result__pb2.toi__pb2
except AttributeError:
  toi__pb2 = result__pb2.toi_pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
from terrascope_api.models import analysis_pb2 as analysis__pb2
try:
  common__models__pb2 = analysis__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__pb2.common_models_pb2
from terrascope_api.models import algorithm_config_pb2 as algorithm__config__pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__config__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = algorithm__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = algorithm__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__config__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
from terrascope_api.models import visualization_pb2 as visualization__pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.result_pb2 import *
from terrascope_api.models.analysis_pb2 import *
from terrascope_api.models.algorithm_config_pb2 import *
from terrascope_api.models.visualization_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14project_result.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x0cresult.proto\x1a\x0e\x61nalysis.proto\x1a\x16\x61lgorithm_config.proto\x1a\x13visualization.proto\"\x82\x02\n\x13ProjectResultStatus\x12\x1a\n\x12\x61nalysis_config_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61oi_id\x18\x02 \x01(\t\x12M\n\x10result_indicator\x18\x03 \x01(\x0e\x32\x33.oi.papi.ProjectResultStatus.ProjectResultIndicator\"p\n\x16ProjectResultIndicator\x12\x19\n\x15UNKNOWN_RESULT_STATUS\x10\x00\x12\x0f\n\x0bNOT_STARTED\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\r\n\tAVAILABLE\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\"\xf5\x02\n\x1aProjectResultDownloadInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x38\n\x14observation_start_ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12observation_end_ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\tfile_type\x18\x04 \x01(\x0e\x32\x41.oi.papi.ProjectResultDownloadInput.ProjectResultDownloadFileType\x12\x11\n\tdata_type\x18\x05 \x01(\t\"h\n\x1dProjectResultDownloadFileType\x12\x15\n\x11UNKNOWN_FILE_TYPE\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\r\n\tSHAPEFILE\x10\x02\x12\x0b\n\x07GEOJSON\x10\x03\x12\x0b\n\x07PARQUET\x10\x04\"\xfb\x02\n\x1bProjectResultDownloadOutput\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12Y\n\x0f\x64ownload_status\x18\x02 \x01(\x0e\x32@.oi.papi.ProjectResultDownloadOutput.ProjectResultDownloadStatus\x12.\n\ncreated_ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66ile_size_bytes\x18\x04 \x01(\r\x12;\n\x0e\x64ownload_input\x18\x05 \x01(\x0b\x32#.oi.papi.ProjectResultDownloadInput\"e\n\x1bProjectResultDownloadStatus\x12\x1b\n\x17UNKNOWN_DOWNLOAD_STATUS\x10\x00\x12\x0e\n\nPROCESSING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\"\xbd\x01\n\rProjectResult\x12\x37\n\x13result_get_response\x18\x01 \x01(\x0b\x32\x1a.oi.papi.ResultGetResponse\x12?\n\x17\x61nalysis_algorithm_node\x18\x02 \x01(\x0b\x32\x1e.oi.papi.AnalysisAlgorithmNode\x12\x32\n\x10\x61lgorithm_config\x18\x03 \x01(\x0b\x32\x18.oi.papi.AlgorithmConfig\"\xf1\x01\n\x17ProjectResultGetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1a\n\x12\x61nalysis_config_id\x18\x02 \x01(\t\x12\x1a\n\x12source_aoi_version\x18\x03 \x01(\r\x12I\n\x0fvisualizer_type\x18\x04 \x01(\x0e\x32\x30.oi.papi.visualization.Visualizer.VisualizerType\x12\x1c\n\x14include_export_files\x18\x05 \x01(\x08\x12!\n\x19include_measurement_files\x18\x06 \x01(\x08\"`\n\x18ProjectResultGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12/\n\x0fproject_results\x18\x02 \x03(\x0b\x32\x16.oi.papi.ProjectResult\"3\n\x1dProjectResultGetStatusRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\xef\x01\n\x1eProjectResultGetStatusResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x34\n\x0eresults_status\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectResultStatus\x12\x42\n\x08progress\x18\x03 \x01(\x0b\x32\x30.oi.papi.ProjectResultGetStatusResponse.Progress\x1a>\n\x08Progress\x12\x0f\n\x07running\x18\x01 \x01(\x01\x12\x11\n\tsucceeded\x18\x02 \x01(\x01\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x01\"^\n\x1fProjectResultGetDownloadRequest\x12;\n\x0e\x64ownload_input\x18\x01 \x01(\x0b\x32#.oi.papi.ProjectResultDownloadInput\"w\n ProjectResultGetDownloadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12>\n\x10\x64ownload_outputs\x18\x02 \x03(\x0b\x32$.oi.papi.ProjectResultDownloadOutput\"c\n$ProjectResultGenerateDownloadRequest\x12;\n\x0e\x64ownload_input\x18\x01 \x01(\x0b\x32#.oi.papi.ProjectResultDownloadInput\"<\n%ProjectResultGenerateDownloadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x96\x03\n\x10ProjectResultApi\x12J\n\x03get\x12 .oi.papi.ProjectResultGetRequest\x1a!.oi.papi.ProjectResultGetResponse\x12]\n\nget_status\x12&.oi.papi.ProjectResultGetStatusRequest\x1a\'.oi.papi.ProjectResultGetStatusResponse\x12\x63\n\x0cget_download\x12(.oi.papi.ProjectResultGetDownloadRequest\x1a).oi.papi.ProjectResultGetDownloadResponse\x12r\n\x11generate_download\x12-.oi.papi.ProjectResultGenerateDownloadRequest\x1a..oi.papi.ProjectResultGenerateDownloadResponseP\x01P\x02P\x03P\x04P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTRESULTSTATUS']._serialized_start=163
  _globals['_PROJECTRESULTSTATUS']._serialized_end=421
  _globals['_PROJECTRESULTSTATUS_PROJECTRESULTINDICATOR']._serialized_start=309
  _globals['_PROJECTRESULTSTATUS_PROJECTRESULTINDICATOR']._serialized_end=421
  _globals['_PROJECTRESULTDOWNLOADINPUT']._serialized_start=424
  _globals['_PROJECTRESULTDOWNLOADINPUT']._serialized_end=797
  _globals['_PROJECTRESULTDOWNLOADINPUT_PROJECTRESULTDOWNLOADFILETYPE']._serialized_start=693
  _globals['_PROJECTRESULTDOWNLOADINPUT_PROJECTRESULTDOWNLOADFILETYPE']._serialized_end=797
  _globals['_PROJECTRESULTDOWNLOADOUTPUT']._serialized_start=800
  _globals['_PROJECTRESULTDOWNLOADOUTPUT']._serialized_end=1179
  _globals['_PROJECTRESULTDOWNLOADOUTPUT_PROJECTRESULTDOWNLOADSTATUS']._serialized_start=1078
  _globals['_PROJECTRESULTDOWNLOADOUTPUT_PROJECTRESULTDOWNLOADSTATUS']._serialized_end=1179
  _globals['_PROJECTRESULT']._serialized_start=1182
  _globals['_PROJECTRESULT']._serialized_end=1371
  _globals['_PROJECTRESULTGETREQUEST']._serialized_start=1374
  _globals['_PROJECTRESULTGETREQUEST']._serialized_end=1615
  _globals['_PROJECTRESULTGETRESPONSE']._serialized_start=1617
  _globals['_PROJECTRESULTGETRESPONSE']._serialized_end=1713
  _globals['_PROJECTRESULTGETSTATUSREQUEST']._serialized_start=1715
  _globals['_PROJECTRESULTGETSTATUSREQUEST']._serialized_end=1766
  _globals['_PROJECTRESULTGETSTATUSRESPONSE']._serialized_start=1769
  _globals['_PROJECTRESULTGETSTATUSRESPONSE']._serialized_end=2008
  _globals['_PROJECTRESULTGETSTATUSRESPONSE_PROGRESS']._serialized_start=1946
  _globals['_PROJECTRESULTGETSTATUSRESPONSE_PROGRESS']._serialized_end=2008
  _globals['_PROJECTRESULTGETDOWNLOADREQUEST']._serialized_start=2010
  _globals['_PROJECTRESULTGETDOWNLOADREQUEST']._serialized_end=2104
  _globals['_PROJECTRESULTGETDOWNLOADRESPONSE']._serialized_start=2106
  _globals['_PROJECTRESULTGETDOWNLOADRESPONSE']._serialized_end=2225
  _globals['_PROJECTRESULTGENERATEDOWNLOADREQUEST']._serialized_start=2227
  _globals['_PROJECTRESULTGENERATEDOWNLOADREQUEST']._serialized_end=2326
  _globals['_PROJECTRESULTGENERATEDOWNLOADRESPONSE']._serialized_start=2328
  _globals['_PROJECTRESULTGENERATEDOWNLOADRESPONSE']._serialized_end=2388
  _globals['_PROJECTRESULTAPI']._serialized_start=2391
  _globals['_PROJECTRESULTAPI']._serialized_end=2797
# @@protoc_insertion_point(module_scope)



from google.protobuf import struct_pb2 as _struct_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import algorithm_pb2 as _algorithm_pb2
import common_models_pb2 as _common_models_pb2_1
import algorithm_version_pb2 as _algorithm_version_pb2
import common_models_pb2 as _common_models_pb2_1_1
import algorithm_pb2 as _algorithm_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from algorithm_pb2 import Algorithm as Algorithm
from algorithm_pb2 import AlgorithmCreateRequest as AlgorithmCreateRequest
from algorithm_pb2 import AlgorithmCreateResponse as AlgorithmCreateResponse
from algorithm_pb2 import AlgorithmGetRequest as AlgorithmGetRequest
from algorithm_pb2 import AlgorithmGetResponse as AlgorithmGetResponse
from algorithm_pb2 import AlgorithmListRequest as AlgorithmListRequest
from algorithm_pb2 import AlgorithmListResponse as AlgorithmListResponse
from algorithm_pb2 import AlgorithmUpdateRequest as AlgorithmUpdateRequest
from algorithm_pb2 import AlgorithmUpdateResponse as AlgorithmUpdateResponse
from algorithm_version_pb2 import Manifest as Manifest
from algorithm_version_pb2 import AlgorithmVersion as AlgorithmVersion
from algorithm_version_pb2 import AlgorithmVersionCreateRequest as AlgorithmVersionCreateRequest
from algorithm_version_pb2 import AlgorithmVersionCreateResponse as AlgorithmVersionCreateResponse
from algorithm_version_pb2 import AlgorithmVersionGetRequest as AlgorithmVersionGetRequest
from algorithm_version_pb2 import AlgorithmVersionGetResponse as AlgorithmVersionGetResponse
from algorithm_version_pb2 import AlgorithmVersionListRequest as AlgorithmVersionListRequest
from algorithm_version_pb2 import AlgorithmVersionListResponse as AlgorithmVersionListResponse
from algorithm_version_pb2 import AlgorithmVersionDeprecateRequest as AlgorithmVersionDeprecateRequest
from algorithm_version_pb2 import AlgorithmVersionDeprecateResponse as AlgorithmVersionDeprecateResponse
from algorithm_version_pb2 import AlgorithmVersionDeactivateRequest as AlgorithmVersionDeactivateRequest
from algorithm_version_pb2 import AlgorithmVersionDeactivateResponse as AlgorithmVersionDeactivateResponse
from algorithm_version_pb2 import AlgorithmVersionActivateRequest as AlgorithmVersionActivateRequest
from algorithm_version_pb2 import AlgorithmVersionActivateResponse as AlgorithmVersionActivateResponse

DESCRIPTOR: _descriptor.FileDescriptor

class AlgorithmConfig(_message.Message):
    __slots__ = ("id", "algorithm_version", "config", "algorithm", "created_on", "is_deactivated", "is_deprecated", "name", "description", "resources_locked")
    ID_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSION_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    IS_DEACTIVATED_FIELD_NUMBER: _ClassVar[int]
    IS_DEPRECATED_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_LOCKED_FIELD_NUMBER: _ClassVar[int]
    id: str
    algorithm_version: _algorithm_version_pb2.AlgorithmVersion
    config: _struct_pb2.Struct
    algorithm: _algorithm_pb2_1.Algorithm
    created_on: _timestamp_pb2.Timestamp
    is_deactivated: bool
    is_deprecated: bool
    name: str
    description: str
    resources_locked: bool
    def __init__(self, id: _Optional[str] = ..., algorithm_version: _Optional[_Union[_algorithm_version_pb2.AlgorithmVersion, _Mapping]] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., algorithm: _Optional[_Union[_algorithm_pb2_1.Algorithm, _Mapping]] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., is_deactivated: bool = ..., is_deprecated: bool = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., resources_locked: bool = ...) -> None: ...

class AlgorithmConfigCreateRequest(_message.Message):
    __slots__ = ("algorithm_version_id", "params", "name", "description")
    ALGORITHM_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    algorithm_version_id: str
    params: _struct_pb2.Struct
    name: str
    description: str
    def __init__(self, algorithm_version_id: _Optional[str] = ..., params: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class AlgorithmConfigCreateResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_config")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_config: AlgorithmConfig
    def __init__(self, status_code: _Optional[int] = ..., algorithm_config: _Optional[_Union[AlgorithmConfig, _Mapping]] = ...) -> None: ...

class AlgorithmConfigUpdateRequest(_message.Message):
    __slots__ = ("id", "algorithm_config")
    ID_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_FIELD_NUMBER: _ClassVar[int]
    id: str
    algorithm_config: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., algorithm_config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class AlgorithmConfigUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AlgorithmConfigGetRequest(_message.Message):
    __slots__ = ("ids", "algorithm_id", "pagination", "algorithm_version_id")
    IDS_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    algorithm_id: str
    pagination: _common_models_pb2_1_1.Pagination
    algorithm_version_id: str
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., algorithm_id: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ..., algorithm_version_id: _Optional[str] = ...) -> None: ...

class AlgorithmConfigGetResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_configs", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_configs: _containers.RepeatedCompositeFieldContainer[AlgorithmConfig]
    pagination: _common_models_pb2_1_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., algorithm_configs: _Optional[_Iterable[_Union[AlgorithmConfig, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmConfigListRequest(_message.Message):
    __slots__ = ("algorithm_id", "algorithm_version_id", "search_text", "min_created_on", "max_created_on", "include_deactivated", "pagination")
    ALGORITHM_ID_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_DEACTIVATED_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    algorithm_id: str
    algorithm_version_id: str
    search_text: str
    min_created_on: _timestamp_pb2.Timestamp
    max_created_on: _timestamp_pb2.Timestamp
    include_deactivated: bool
    pagination: _common_models_pb2_1_1.Pagination
    def __init__(self, algorithm_id: _Optional[str] = ..., algorithm_version_id: _Optional[str] = ..., search_text: _Optional[str] = ..., min_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., include_deactivated: bool = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmConfigListResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_configs", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_configs: _containers.RepeatedCompositeFieldContainer[AlgorithmConfig]
    pagination: _common_models_pb2_1_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., algorithm_configs: _Optional[_Iterable[_Union[AlgorithmConfig, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1_1.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmConfigDeleteRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmConfigDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AlgorithmConfigDeprecateRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmConfigDeprecateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AlgorithmConfigDeactivateRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmConfigDeactivateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"7\n\rLoginResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t\"G\n\x19UserChangePasswordRequest\x12\x14\n\x0cold_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"1\n\x1aUserChangePasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"5\n\x1fUserGenerateTempPasswordRequest\x12\x12\n\nuser_email\x18\x01 \x01(\t\"M\n UserGenerateTempPasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"L\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x1b\n\x13user_collection_ids\x18\x04 \x03(\t\"L\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12user_collection_id\x18\x03 \x01(\t\"F\n\x12UserCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.oi.papi.User\"0\n\x11UserUpdateRequest\x12\x1b\n\x04user\x18\x01 \x01(\x0b\x32\r.oi.papi.User\")\n\x12UserUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"$\n\x11UserDeleteRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\")\n\x12UserDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"-\n\x0eUserGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0e\n\x06\x65mails\x18\x02 \x03(\t\"D\n\x0fUserGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\" \n\x0fUserListRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x10UserListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1a\n\x18UserPropertiesGetRequest\"[\n\x19UserPropertiesGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\nproperties\x18\x02 \x03(\x0b\x32\x15.oi.papi.KeyValuePair\"]\n\x1bUserPropertiesUpdateRequest\x12)\n\nproperties\x18\x01 \x03(\x0b\x32\x15.oi.papi.KeyValuePair\x12\x13\n\x0breplace_all\x18\x02 \x01(\x08\"3\n\x1cUserPropertiesUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x16\n\x14UserPublicKeyRequest\"=\n\x15UserPublicKeyResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07key_pem\x18\x02 \x01(\t2\xd8\x06\n\x07UserApi\x12\x36\n\x05login\x12\x15.oi.papi.LoginRequest\x1a\x16.oi.papi.LoginResponse\x12Z\n\x0f\x63hange_password\x12\".oi.papi.UserChangePasswordRequest\x1a#.oi.papi.UserChangePasswordResponse\x12m\n\x16generate_temp_password\x12(.oi.papi.UserGenerateTempPasswordRequest\x1a).oi.papi.UserGenerateTempPasswordResponse\x12\x41\n\x06\x63reate\x12\x1a.oi.papi.UserCreateRequest\x1a\x1b.oi.papi.UserCreateResponse\x12\x38\n\x03get\x12\x17.oi.papi.UserGetRequest\x1a\x18.oi.papi.UserGetResponse\x12\x41\n\x06update\x12\x1a.oi.papi.UserUpdateRequest\x1a\x1b.oi.papi.UserUpdateResponse\x12\x41\n\x06\x64\x65lete\x12\x1a.oi.papi.UserDeleteRequest\x1a\x1b.oi.papi.UserDeleteResponse\x12;\n\x04list\x12\x18.oi.papi.UserListRequest\x1a\x19.oi.papi.UserListResponse\x12W\n\x0eget_properties\x12!.oi.papi.UserPropertiesGetRequest\x1a\".oi.papi.UserPropertiesGetResponse\x12`\n\x11update_properties\x12$.oi.papi.UserPropertiesUpdateRequest\x1a%.oi.papi.UserPropertiesUpdateResponse\x12O\n\x0eget_public_key\x12\x1d.oi.papi.UserPublicKeyRequest\x1a\x1e.oi.papi.UserPublicKeyResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOGINREQUEST']._serialized_start=44
  _globals['_LOGINREQUEST']._serialized_end=91
  _globals['_LOGINRESPONSE']._serialized_start=93
  _globals['_LOGINRESPONSE']._serialized_end=148
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_start=150
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_end=221
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_start=223
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_end=272
  _globals['_USERGENERATETEMPPASSWORDREQUEST']._serialized_start=274
  _globals['_USERGENERATETEMPPASSWORDREQUEST']._serialized_end=327
  _globals['_USERGENERATETEMPPASSWORDRESPONSE']._serialized_start=329
  _globals['_USERGENERATETEMPPASSWORDRESPONSE']._serialized_end=406
  _globals['_USER']._serialized_start=408
  _globals['_USER']._serialized_end=484
  _globals['_USERCREATEREQUEST']._serialized_start=486
  _globals['_USERCREATEREQUEST']._serialized_end=562
  _globals['_USERCREATERESPONSE']._serialized_start=564
  _globals['_USERCREATERESPONSE']._serialized_end=634
  _globals['_USERUPDATEREQUEST']._serialized_start=636
  _globals['_USERUPDATEREQUEST']._serialized_end=684
  _globals['_USERUPDATERESPONSE']._serialized_start=686
  _globals['_USERUPDATERESPONSE']._serialized_end=727
  _globals['_USERDELETEREQUEST']._serialized_start=729
  _globals['_USERDELETEREQUEST']._serialized_end=765
  _globals['_USERDELETERESPONSE']._serialized_start=767
  _globals['_USERDELETERESPONSE']._serialized_end=808
  _globals['_USERGETREQUEST']._serialized_start=810
  _globals['_USERGETREQUEST']._serialized_end=855
  _globals['_USERGETRESPONSE']._serialized_start=857
  _globals['_USERGETRESPONSE']._serialized_end=925
  _globals['_USERLISTREQUEST']._serialized_start=927
  _globals['_USERLISTREQUEST']._serialized_end=959
  _globals['_USERLISTRESPONSE']._serialized_start=961
  _globals['_USERLISTRESPONSE']._serialized_end=1030
  _globals['_KEYVALUEPAIR']._serialized_start=1032
  _globals['_KEYVALUEPAIR']._serialized_end=1074
  _globals['_USERPROPERTIESGETREQUEST']._serialized_start=1076
  _globals['_USERPROPERTIESGETREQUEST']._serialized_end=1102
  _globals['_USERPROPERTIESGETRESPONSE']._serialized_start=1104
  _globals['_USERPROPERTIESGETRESPONSE']._serialized_end=1195
  _globals['_USERPROPERTIESUPDATEREQUEST']._serialized_start=1197
  _globals['_USERPROPERTIESUPDATEREQUEST']._serialized_end=1290
  _globals['_USERPROPERTIESUPDATERESPONSE']._serialized_start=1292
  _globals['_USERPROPERTIESUPDATERESPONSE']._serialized_end=1343
  _globals['_USERPUBLICKEYREQUEST']._serialized_start=1345
  _globals['_USERPUBLICKEYREQUEST']._serialized_end=1367
  _globals['_USERPUBLICKEYRESPONSE']._serialized_start=1369
  _globals['_USERPUBLICKEYRESPONSE']._serialized_end=1430
  _globals['_USERAPI']._serialized_start=1433
  _globals['_USERAPI']._serialized_end=2289
# @@protoc_insertion_point(module_scope)



import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class LoginRequest(_message.Message):
    __slots__ = ("email", "password")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    email: str
    password: str
    def __init__(self, email: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class LoginResponse(_message.Message):
    __slots__ = ("status_code", "jwt_token")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    JWT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    jwt_token: str
    def __init__(self, status_code: _Optional[int] = ..., jwt_token: _Optional[str] = ...) -> None: ...

class UserChangePasswordRequest(_message.Message):
    __slots__ = ("old_password", "new_password")
    OLD_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    NEW_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    old_password: str
    new_password: str
    def __init__(self, old_password: _Optional[str] = ..., new_password: _Optional[str] = ...) -> None: ...

class UserChangePasswordResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserGenerateTempPasswordRequest(_message.Message):
    __slots__ = ("user_email",)
    USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    user_email: str
    def __init__(self, user_email: _Optional[str] = ...) -> None: ...

class UserGenerateTempPasswordResponse(_message.Message):
    __slots__ = ("status_code", "new_password")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    NEW_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    new_password: str
    def __init__(self, status_code: _Optional[int] = ..., new_password: _Optional[str] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ("id", "name", "email", "user_collection_ids")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    USER_COLLECTION_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    email: str
    user_collection_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., email: _Optional[str] = ..., user_collection_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class UserCreateRequest(_message.Message):
    __slots__ = ("name", "email", "user_collection_id")
    NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    USER_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    email: str
    user_collection_id: str
    def __init__(self, name: _Optional[str] = ..., email: _Optional[str] = ..., user_collection_id: _Optional[str] = ...) -> None: ...

class UserCreateResponse(_message.Message):
    __slots__ = ("status_code", "user")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    USER_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    user: User
    def __init__(self, status_code: _Optional[int] = ..., user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class UserUpdateRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class UserUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserDeleteRequest(_message.Message):
    __slots__ = ("user_id",)
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class UserDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserGetRequest(_message.Message):
    __slots__ = ("ids", "emails")
    IDS_FIELD_NUMBER: _ClassVar[int]
    EMAILS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    emails: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., emails: _Optional[_Iterable[str]] = ...) -> None: ...

class UserGetResponse(_message.Message):
    __slots__ = ("status_code", "users")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    users: _containers.RepeatedCompositeFieldContainer[User]
    def __init__(self, status_code: _Optional[int] = ..., users: _Optional[_Iterable[_Union[User, _Mapping]]] = ...) -> None: ...

class UserListRequest(_message.Message):
    __slots__ = ("email",)
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class UserListResponse(_message.Message):
    __slots__ = ("status_code", "users")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    USERS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    users: _containers.RepeatedCompositeFieldContainer[User]
    def __init__(self, status_code: _Optional[int] = ..., users: _Optional[_Iterable[_Union[User, _Mapping]]] = ...) -> None: ...

class KeyValuePair(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class UserPropertiesGetRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UserPropertiesGetResponse(_message.Message):
    __slots__ = ("status_code", "properties")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    properties: _containers.RepeatedCompositeFieldContainer[KeyValuePair]
    def __init__(self, status_code: _Optional[int] = ..., properties: _Optional[_Iterable[_Union[KeyValuePair, _Mapping]]] = ...) -> None: ...

class UserPropertiesUpdateRequest(_message.Message):
    __slots__ = ("properties", "replace_all")
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    REPLACE_ALL_FIELD_NUMBER: _ClassVar[int]
    properties: _containers.RepeatedCompositeFieldContainer[KeyValuePair]
    replace_all: bool
    def __init__(self, properties: _Optional[_Iterable[_Union[KeyValuePair, _Mapping]]] = ..., replace_all: bool = ...) -> None: ...

class UserPropertiesUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class UserPublicKeyRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UserPublicKeyResponse(_message.Message):
    __slots__ = ("status_code", "key_pem")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    KEY_PEM_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    key_pem: str
    def __init__(self, status_code: _Optional[int] = ..., key_pem: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: algorithm_version.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'algorithm_version.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import algorithm_pb2 as algorithm__pb2
try:
  common__models__pb2 = algorithm__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.algorithm_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61lgorithm_version.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x0f\x61lgorithm.proto\"\xa4\x08\n\x08Manifest\x12,\n\x08metadata\x18\x01 \x01(\x0b\x32\x1a.oi.papi.Manifest.Metadata\x12\x31\n\x06inputs\x18\x02 \x03(\x0b\x32!.oi.papi.Manifest.AlgorithmInputs\x12\x33\n\x07outputs\x18\x03 \x03(\x0b\x32\".oi.papi.Manifest.AlgorithmOutputs\x12\x43\n\x14\x63ontainer_parameters\x18\x04 \x01(\x0b\x32%.oi.papi.Manifest.ContainerParameters\x12.\n\tinterface\x18\x05 \x01(\x0b\x32\x1b.oi.papi.Manifest.Interface\x12;\n\x10resource_request\x18\x06 \x01(\x0b\x32!.oi.papi.Manifest.ResourceRequest\x12/\n\nparameters\x18\x07 \x03(\x0b\x32\x1b.oi.papi.Manifest.Parameter\x12\x18\n\x10manifest_version\x18\x08 \x01(\t\x1a\x44\n\x08Metadata\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\tJ\x04\x08\x01\x10\x02\x1a\x34\n\tInterface\x12\x16\n\x0einterface_type\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\x1aO\n\x0f\x41lgorithmInputs\x12\x16\n\x0e\x64\x61ta_type_name\x18\x01 \x01(\t\x12\x11\n\tmin_count\x18\x02 \x01(\r\x12\x11\n\tmax_count\x18\x03 \x01(\r\x1aS\n\x10\x41lgorithmOutputs\x12!\n\x19observation_value_columns\x18\x02 \x03(\t\x12\x16\n\x0e\x64\x61ta_type_name\x18\x03 \x01(\tJ\x04\x08\x01\x10\x02\x1ar\n\x13\x43ontainerParameters\x12\r\n\x05image\x18\x01 \x01(\t\x12;\n\x10resource_request\x18\x02 \x01(\x0b\x32!.oi.papi.Manifest.ResourceRequest\x12\x0f\n\x07\x63ommand\x18\x03 \x03(\t\x1a^\n\x0fResourceRequest\x12\x0b\n\x03gpu\x18\x01 \x01(\r\x12\x11\n\tmemory_gb\x18\x02 \x01(\r\x12\x15\n\rcpu_millicore\x18\x03 \x01(\r\x12\x14\n\x0cmax_input_gb\x18\x04 \x01(\x01\x1a\x8e\x01\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\r\n\x05units\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0b\n\x03min\x18\x05 \x01(\r\x12\x0b\n\x03max\x18\x06 \x01(\r\x12\x16\n\x0e\x61llowed_values\x18\x07 \x03(\t\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x08 \x01(\r\"\xe0\x01\n\x10\x41lgorithmVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12%\n\talgorithm\x18\x02 \x01(\x0b\x32\x12.oi.papi.Algorithm\x12\x0f\n\x07version\x18\x03 \x01(\t\x12)\n\x08manifest\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0eis_deactivated\x18\x06 \x01(\x08\x12\x15\n\ris_deprecated\x18\x07 \x01(\x08\"\xae\x01\n\x1d\x41lgorithmVersionCreateRequest\x12\x14\n\x0c\x61lgorithm_id\x18\x01 \x01(\t\x12\x32\n\x0fmanifest_struct\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12-\n\x10manifest_message\x18\x03 \x01(\x0b\x32\x11.oi.papi.ManifestH\x00\x42\x14\n\x12\x61lgorithm_manifest\"k\n\x1e\x41lgorithmVersionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x34\n\x11\x61lgorithm_version\x18\x02 \x01(\x0b\x32\x19.oi.papi.AlgorithmVersion\"R\n\x1a\x41lgorithmVersionGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x92\x01\n\x1b\x41lgorithmVersionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x35\n\x12\x61lgorithm_versions\x18\x02 \x03(\x0b\x32\x19.oi.papi.AlgorithmVersion\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x84\x02\n\x1b\x41lgorithmVersionListRequest\x12\x14\n\x0c\x61lgorithm_id\x18\x01 \x01(\t\x12\x13\n\x0bsearch_text\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x32\n\x0emin_created_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14include_all_versions\x18\x06 \x01(\x08\x12\'\n\npagination\x18\x07 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x93\x01\n\x1c\x41lgorithmVersionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x35\n\x12\x61lgorithm_versions\x18\x02 \x03(\x0b\x32\x19.oi.papi.AlgorithmVersion\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"/\n AlgorithmVersionDeprecateRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"8\n!AlgorithmVersionDeprecateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"0\n!AlgorithmVersionDeactivateRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"9\n\"AlgorithmVersionDeactivateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\".\n\x1f\x41lgorithmVersionActivateRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"7\n AlgorithmVersionActivateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xc3\x04\n\x13\x41lgorithmVersionApi\x12Y\n\x06\x63reate\x12&.oi.papi.AlgorithmVersionCreateRequest\x1a\'.oi.papi.AlgorithmVersionCreateResponse\x12P\n\x03get\x12#.oi.papi.AlgorithmVersionGetRequest\x1a$.oi.papi.AlgorithmVersionGetResponse\x12S\n\x04list\x12$.oi.papi.AlgorithmVersionListRequest\x1a%.oi.papi.AlgorithmVersionListResponse\x12\x62\n\tdeprecate\x12).oi.papi.AlgorithmVersionDeprecateRequest\x1a*.oi.papi.AlgorithmVersionDeprecateResponse\x12\x65\n\ndeactivate\x12*.oi.papi.AlgorithmVersionDeactivateRequest\x1a+.oi.papi.AlgorithmVersionDeactivateResponse\x12_\n\x08\x61\x63tivate\x12(.oi.papi.AlgorithmVersionActivateRequest\x1a).oi.papi.AlgorithmVersionActivateResponseP\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MANIFEST']._serialized_start=138
  _globals['_MANIFEST']._serialized_end=1198
  _globals['_MANIFEST_METADATA']._serialized_start=553
  _globals['_MANIFEST_METADATA']._serialized_end=621
  _globals['_MANIFEST_INTERFACE']._serialized_start=623
  _globals['_MANIFEST_INTERFACE']._serialized_end=675
  _globals['_MANIFEST_ALGORITHMINPUTS']._serialized_start=677
  _globals['_MANIFEST_ALGORITHMINPUTS']._serialized_end=756
  _globals['_MANIFEST_ALGORITHMOUTPUTS']._serialized_start=758
  _globals['_MANIFEST_ALGORITHMOUTPUTS']._serialized_end=841
  _globals['_MANIFEST_CONTAINERPARAMETERS']._serialized_start=843
  _globals['_MANIFEST_CONTAINERPARAMETERS']._serialized_end=957
  _globals['_MANIFEST_RESOURCEREQUEST']._serialized_start=959
  _globals['_MANIFEST_RESOURCEREQUEST']._serialized_end=1053
  _globals['_MANIFEST_PARAMETER']._serialized_start=1056
  _globals['_MANIFEST_PARAMETER']._serialized_end=1198
  _globals['_ALGORITHMVERSION']._serialized_start=1201
  _globals['_ALGORITHMVERSION']._serialized_end=1425
  _globals['_ALGORITHMVERSIONCREATEREQUEST']._serialized_start=1428
  _globals['_ALGORITHMVERSIONCREATEREQUEST']._serialized_end=1602
  _globals['_ALGORITHMVERSIONCREATERESPONSE']._serialized_start=1604
  _globals['_ALGORITHMVERSIONCREATERESPONSE']._serialized_end=1711
  _globals['_ALGORITHMVERSIONGETREQUEST']._serialized_start=1713
  _globals['_ALGORITHMVERSIONGETREQUEST']._serialized_end=1795
  _globals['_ALGORITHMVERSIONGETRESPONSE']._serialized_start=1798
  _globals['_ALGORITHMVERSIONGETRESPONSE']._serialized_end=1944
  _globals['_ALGORITHMVERSIONLISTREQUEST']._serialized_start=1947
  _globals['_ALGORITHMVERSIONLISTREQUEST']._serialized_end=2207
  _globals['_ALGORITHMVERSIONLISTRESPONSE']._serialized_start=2210
  _globals['_ALGORITHMVERSIONLISTRESPONSE']._serialized_end=2357
  _globals['_ALGORITHMVERSIONDEPRECATEREQUEST']._serialized_start=2359
  _globals['_ALGORITHMVERSIONDEPRECATEREQUEST']._serialized_end=2406
  _globals['_ALGORITHMVERSIONDEPRECATERESPONSE']._serialized_start=2408
  _globals['_ALGORITHMVERSIONDEPRECATERESPONSE']._serialized_end=2464
  _globals['_ALGORITHMVERSIONDEACTIVATEREQUEST']._serialized_start=2466
  _globals['_ALGORITHMVERSIONDEACTIVATEREQUEST']._serialized_end=2514
  _globals['_ALGORITHMVERSIONDEACTIVATERESPONSE']._serialized_start=2516
  _globals['_ALGORITHMVERSIONDEACTIVATERESPONSE']._serialized_end=2573
  _globals['_ALGORITHMVERSIONACTIVATEREQUEST']._serialized_start=2575
  _globals['_ALGORITHMVERSIONACTIVATEREQUEST']._serialized_end=2621
  _globals['_ALGORITHMVERSIONACTIVATERESPONSE']._serialized_start=2623
  _globals['_ALGORITHMVERSIONACTIVATERESPONSE']._serialized_end=2678
  _globals['_ALGORITHMVERSIONAPI']._serialized_start=2681
  _globals['_ALGORITHMVERSIONAPI']._serialized_end=3260
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: algorithm_manifest.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'algorithm_manifest.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61lgorithm_manifest.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"4\n!AlgorithmManifestSchemaGetRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\"s\n\"AlgorithmManifestSchemaGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\'\n\x06schema\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct2v\n\x14\x41lgorithmManifestApi\x12^\n\x03get\x12*.oi.papi.AlgorithmManifestSchemaGetRequest\x1a+.oi.papi.AlgorithmManifestSchemaGetResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_manifest_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALGORITHMMANIFESTSCHEMAGETREQUEST']._serialized_start=88
  _globals['_ALGORITHMMANIFESTSCHEMAGETREQUEST']._serialized_end=140
  _globals['_ALGORITHMMANIFESTSCHEMAGETRESPONSE']._serialized_start=142
  _globals['_ALGORITHMMANIFESTSCHEMAGETRESPONSE']._serialized_end=257
  _globals['_ALGORITHMMANIFESTAPI']._serialized_start=259
  _globals['_ALGORITHMMANIFESTAPI']._serialized_end=377
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Pagination(_message.Message):
    __slots__ = ("page_token", "page_size", "next_page_token")
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    page_token: str
    page_size: int
    next_page_token: str
    def __init__(self, page_token: _Optional[str] = ..., page_size: _Optional[int] = ..., next_page_token: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: aoi_transaction.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'aoi_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.aoi_pb2 import *
from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61oi_transaction.proto\x12\x07oi.papi\x1a\taoi.proto\x1a\x13\x63ommon_models.proto\")\n\x1b\x41OITransactionStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\"a\n\x1c\x41OITransactionStatusResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\x0btransaction\x18\x02 \x01(\x0b\x32\x17.oi.papi.AOITransaction\"O\n\x18\x41OITransactionGetRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\n\n\x02id\x18\x02 \x01(\t\"\x8a\x01\n\x19\x41OITransactionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12/\n\x0f\x61oi_identifiers\x18\x03 \x03(\x0b\x32\x16.oi.papi.AOIIdentifier2\xb8\x01\n\x11\x41OITransactionApi\x12L\n\x03get\x12!.oi.papi.AOITransactionGetRequest\x1a\".oi.papi.AOITransactionGetResponse\x12U\n\x06status\x12$.oi.papi.AOITransactionStatusRequest\x1a%.oi.papi.AOITransactionStatusResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AOITRANSACTIONSTATUSREQUEST']._serialized_start=66
  _globals['_AOITRANSACTIONSTATUSREQUEST']._serialized_end=107
  _globals['_AOITRANSACTIONSTATUSRESPONSE']._serialized_start=109
  _globals['_AOITRANSACTIONSTATUSRESPONSE']._serialized_end=206
  _globals['_AOITRANSACTIONGETREQUEST']._serialized_start=208
  _globals['_AOITRANSACTIONGETREQUEST']._serialized_end=287
  _globals['_AOITRANSACTIONGETRESPONSE']._serialized_start=290
  _globals['_AOITRANSACTIONGETRESPONSE']._serialized_end=428
  _globals['_AOITRANSACTIONAPI']._serialized_start=431
  _globals['_AOITRANSACTIONAPI']._serialized_end=615
# @@protoc_insertion_point(module_scope)
